@@ -569,7 +569,7 @@ gst_dvd_sub_dec_merge_title (GstDvdSubDec * dec, GstVideoFrame * frame)
   gint hl_top, hl_bottom;
   gint last_y;
   RLE_state state;
-  guint8 *Y_data;;
+  guint8 *Y_data;
 
   GST_DEBUG_OBJECT (dec, "Merging subtitle on frame");
 
@@ -692,8 +692,7 @@ gst_send_subtitle_frame (GstDvdSubDec * dec, GstClockTime end_ts)
   }
 
   out_buf =
-      gst_buffer_new_allocate (NULL, GST_VIDEO_INFO_SIZE (&dec->info),
-      &params);
+      gst_buffer_new_allocate (NULL, GST_VIDEO_INFO_SIZE (&dec->info), &params);
   gst_video_frame_map (&frame, &dec->info, out_buf, GST_MAP_READWRITE);
 
   data = GST_VIDEO_FRAME_PLANE_DATA (&frame, 0);
