@@ -28,7 +28,10 @@
     "layout = (string) interleaved, channels = (int) 1, rate = (int) 8000"
 #define SINK_CAPS "audio/AMR"
 
-static GstPad *srcpad, *sinkpad;
+GList *buffers;
+GList *current_buf = NULL;
+
+GstPad *srcpad, *sinkpad;
 
 static GstStaticPadTemplate sinktemplate = GST_STATIC_PAD_TEMPLATE ("sink",
     GST_PAD_SINK,
@@ -54,6 +57,7 @@ setup_amrnbenc (void)
   GstElement *amrnbenc;
   GstCaps *caps;
   GstBus *bus;
+  guint64 granulerate_n, granulerate_d;
 
   GST_DEBUG ("setup_amrnbenc");
 
